hydra\_zen.ZenStore
===================

.. currentmodule:: hydra_zen

.. autoclass:: ZenStore

   
   .. automethod:: __init__
   .. automethod:: __call__
   .. automethod:: __getitem__
   .. automethod:: add_to_hydra_store
   .. automethod:: get_entry
   .. automethod:: has_enqueued
   .. automethod:: __iter__
   .. automethod:: __eq__
   
   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ZenStore.name
      ~ZenStore.groups
